Date: 2024-03-28
Package: canprot
Version: 2.0.0
Title: Chemical Analysis of Proteins
Authors@R: c(
    person("Jeffrey", "Dick", email = "j3ffdick@gmail.com", role = c("aut", "cre"),
      comment = c(ORCID = "0000-0002-0687-5890"))
    )
Maintainer: Jeffrey Dick <j3ffdick@gmail.com>
Depends: R (>= 3.1.0)
Imports: stringi, multcompView
Suggests: knitr, rmarkdown, tinytest, CHNOSZ (>= 1.3.4)
Description: Chemical analysis of proteins based on their amino acid
  compositions. Amino acid compositions can be read from FASTA files and used to
  calculate chemical metrics including carbon oxidation state and stoichiometric
  hydration state, as described in Dick et al. (2020) <doi:10.5194/bg-17-6145-2020>. 
  Other properties that can be calculated include protein length, grand average of
  hydropathy (GRAVY), isoelectric point (pI), molecular weight (MW), standard
  molal volume (V0), and metabolic costs (Akashi and Gojobori, 2002
  <doi:10.1073/pnas.062526999>; Wagner, 2005 <doi:10.1093/molbev/msi126>;
  Zhang et al., 2018 <doi:10.1038/s41467-018-06461-1>). A database of amino acid
  compositions of human proteins derived from UniProt is provided.
Encoding: UTF-8
License: GPL-3
BuildResaveData: no
VignetteBuilder: knitr
URL: https://github.com/jedick/canprot
NeedsCompilation: no
Packaged: 2024-03-28 06:11:03 UTC; jedick
Author: Jeffrey Dick [aut, cre] (<https://orcid.org/0000-0002-0687-5890>)
Repository: CRAN
Date/Publication: 2024-03-28 16:00:13 UTC
Built: R 4.6.0; ; 2026-04-25 17:20:22 UTC; unix
