# Exported variables
export(
# 20170612 (canprot 0.1.0)
"human_aa", "CLES",
# metrics added 20191005 - 20191027
"Zc", "nH2O", "GRAVY", "pI",
# 20200204 used in JMDplots package
"cplab",
# 20200501
"MW",
# 20200509
"canprot",
# 20201016
"nO2",
# 20240225
"plength",
# 20240228 moved from CHNOSZ
"read_fasta", "count_aa", "sum_aa",
# 20240301
"V0", "add_cld", "pV0",
# 20240302 moved from chem16S
"HC", "NC", "OC", "SC", "calc_metrics",
# 20240304
"pMW", "Density", "Cost",
"RespiratoryCost", "FermentativeCost",
"B20Cost", "Y20Cost", "H11Cost",
# 20240308
"S0", "pS0", "S0g", "V0g",
# 20240309
"SV",
# 20240310 moved from chem16S
"add_hull",
# 20240317
"Zcg", "nO2g", "nH2Og",
# 20240322
"nC", "pnC"
)

# Imports from default packages
importFrom("stats", "pnorm", "sd", "TukeyHSD", "aov")
importFrom("utils", "read.csv", "getFromNamespace")
importFrom("graphics", "text", "par", "polygon")
importFrom("tools", "file_path_sans_ext")
importFrom("grDevices", "chull", "xy.coords")

# Imports from other packages
importFrom("stringi", "stri_count_fixed")
importFrom("multcompView", "multcompLetters4")
